==> gcstar_0.5.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/RU/GCModels/GCfilms.pm <==
{
    package GCLang::RU::GCModels::GCfilms;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Movies collection',
        Items => 'Фильмы',
        NewItem => 'Новый фильм',
    
    
        Id => 'Идентификатор',
        Title => 'Название',
        Date => 'Дата',
        Time => 'Длительность',
        Director => 'Режиссёр',
        Country => 'Страна',
        MinimumAge => 'Минимальный возраст',
        Genre => 'Жанр',
        Image => 'Картинка',
        Original => 'Оригинальный заголовок',
        Actors => 'Актеры',
        Comment => 'Комментарии',
        Synopsis => 'Описание',
        Seen => 'Просмотрен',
        Number => '# носителей',
        Rating => 'Рейтинг',
        Format => 'Носитель',
        Url => 'Web',
        Place => 'Размещение',
        Audio => 'Аудио',
        Video => 'Видео формат',
        Trailer => 'Видео файл',
        Serie => 'Коллеция',
        Rank => 'Rank',
        Subtitles => 'Субтитры',

        SeenYes => 'Смотрел',
        SeenNo => 'Не смотрел',

        AgeUnrated => 'Unbewertet',
        AgeAll => 'Для _Любого возраста',
        AgeParent => 'Под присмотром родителей',

        Main => 'Основное',
        General => 'Общие',
        Details => 'Детали',
        Lending => 'На руках',

        Information => 'Информация',
        Languages => 'Языки',
        Encoding => 'Кодирование',

        FilterAudienceAge => 'Возраст аудитории:',
        FilterSeenNo => 'Нет',
        FilterSeenYes => '_Already Viewed',
        FilterRatingSelect => 'По Крайней мере...',
     );
}

1;

==> gcstar_1.0.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/RU/GCModels/GCfilms.pm <==
{
    package GCLang::RU::GCModels::GCfilms;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Коллекция фильмов',
        Items => 'Фильмы',
        NewItem => 'Новый фильм',
    
    
        Id => 'Идентификатор',
        Title => 'Название',
        Date => 'Дата',
        Time => 'Длительность',
        Director => 'Режиссёр',
        Country => 'Страна',
        MinimumAge => 'Минимальный возраст',
        Genre => 'Жанр',
        Image => 'Картинка',
        Original => 'Оригинальный заголовок',
        Actors => 'Актеры',
        Comment => 'Комментарии',
        Synopsis => 'Описание',
        Seen => 'Просмотрен',
        Number => '# носителей',
        Rating => 'Рейтинг',
        Format => 'Носитель',
        Url => 'ВЭБ',
        Place => 'Размещение',
        Audio => 'Аудио',
        Video => 'Видео формат',
        Trailer => 'Видео файл',
        Serie => 'Коллеция',
        Rank => 'Ранг',
        Subtitles => 'Субтитры',
        Added => 'Добавить дату',

        SeenYes => 'Смотрел',
        SeenNo => 'Не смотрел',

        AgeUnrated => 'Без ограничений',
        AgeAll => 'Для _Любого возраста',
        AgeParent => 'Под присмотром родителей',

        Main => 'Основное',
        General => 'Общие',
        Details => 'Детали',
        Lending => 'На руках',

        Information => 'Информация',
        Languages => 'Языки',
        Encoding => 'Кодирование',

        FilterAudienceAge => 'Возраст аудитории:',
        FilterSeenNo => 'Нет',
        FilterSeenYes => '_Уже просмотрено',
        FilterRatingSelect => 'По Крайней мере...',

        ExtractSize => 'Размер',
     );
}

1;
